.. include:: ../README.rst

Tutorial and Examples
---------------------

.. toctree::
    :maxdepth: 2

    tutorial
    examples

Module index
------------

.. toctree::
   :maxdepth: 1

   _source/modules
